==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEIssuerDNS01ProviderRFC2136Fluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorFluent;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorBuilder;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelector;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEIssuerDNS01ProviderRFC2136Fluent<A extends ACMEIssuerDNS01ProviderRFC2136Fluent<A>> extends BaseFluent<A>{
  public ACMEIssuerDNS01ProviderRFC2136Fluent() {
  }
  public ACMEIssuerDNS01ProviderRFC2136Fluent(ACMEIssuerDNS01ProviderRFC2136 instance) {
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderRFC2136());

    if (instance != null) {
      this.withNameserver(instance.getNameserver());
      this.withTsigAlgorithm(instance.getTsigAlgorithm());
      this.withTsigKeyName(instance.getTsigKeyName());
      this.withTsigSecretSecretRef(instance.getTsigSecretSecretRef());
      this.withNameserver(instance.getNameserver());
      this.withTsigAlgorithm(instance.getTsigAlgorithm());
      this.withTsigKeyName(instance.getTsigKeyName());
      this.withTsigSecretSecretRef(instance.getTsigSecretSecretRef());
    }
  }
  private String nameserver;
  private String tsigAlgorithm;
  private String tsigKeyName;
  private SecretKeySelectorBuilder tsigSecretSecretRef;
  public String getNameserver() {
    return this.nameserver;
  }
  public A withNameserver(String nameserver) {
    this.nameserver=nameserver; return (A) this;
  }
  public boolean hasNameserver() {
    return this.nameserver != null;
  }
  public String getTsigAlgorithm() {
    return this.tsigAlgorithm;
  }
  public A withTsigAlgorithm(String tsigAlgorithm) {
    this.tsigAlgorithm=tsigAlgorithm; return (A) this;
  }
  public boolean hasTsigAlgorithm() {
    return this.tsigAlgorithm != null;
  }
  public String getTsigKeyName() {
    return this.tsigKeyName;
  }
  public A withTsigKeyName(String tsigKeyName) {
    this.tsigKeyName=tsigKeyName; return (A) this;
  }
  public boolean hasTsigKeyName() {
    return this.tsigKeyName != null;
  }
  public SecretKeySelector buildTsigSecretSecretRef() {
    return this.tsigSecretSecretRef!=null ?this.tsigSecretSecretRef.build():null;
  }
  public A withTsigSecretSecretRef(SecretKeySelector tsigSecretSecretRef) {
    _visitables.get("tsigSecretSecretRef").remove(this.tsigSecretSecretRef);
    if (tsigSecretSecretRef!=null){ this.tsigSecretSecretRef= new SecretKeySelectorBuilder(tsigSecretSecretRef); _visitables.get("tsigSecretSecretRef").add(this.tsigSecretSecretRef);} else { this.tsigSecretSecretRef = null; _visitables.get("tsigSecretSecretRef").remove(this.tsigSecretSecretRef); } return (A) this;
  }
  public boolean hasTsigSecretSecretRef() {
    return this.tsigSecretSecretRef != null;
  }
  public A withNewTsigSecretSecretRef(String key,String name) {
    return (A)withTsigSecretSecretRef(new SecretKeySelector(key, name));
  }
  public TsigSecretSecretRefNested<A> withNewTsigSecretSecretRef() {
    return new TsigSecretSecretRefNested(null);
  }
  public TsigSecretSecretRefNested<A> withNewTsigSecretSecretRefLike(SecretKeySelector item) {
    return new TsigSecretSecretRefNested(item);
  }
  public TsigSecretSecretRefNested<A> editTsigSecretSecretRef() {
    return withNewTsigSecretSecretRefLike(java.util.Optional.ofNullable(buildTsigSecretSecretRef()).orElse(null));
  }
  public TsigSecretSecretRefNested<A> editOrNewTsigSecretSecretRef() {
    return withNewTsigSecretSecretRefLike(java.util.Optional.ofNullable(buildTsigSecretSecretRef()).orElse(new SecretKeySelectorBuilder().build()));
  }
  public TsigSecretSecretRefNested<A> editOrNewTsigSecretSecretRefLike(SecretKeySelector item) {
    return withNewTsigSecretSecretRefLike(java.util.Optional.ofNullable(buildTsigSecretSecretRef()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEIssuerDNS01ProviderRFC2136Fluent that = (ACMEIssuerDNS01ProviderRFC2136Fluent) o;
    if (!java.util.Objects.equals(nameserver, that.nameserver)) return false;

    if (!java.util.Objects.equals(tsigAlgorithm, that.tsigAlgorithm)) return false;

    if (!java.util.Objects.equals(tsigKeyName, that.tsigKeyName)) return false;

    if (!java.util.Objects.equals(tsigSecretSecretRef, that.tsigSecretSecretRef)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(nameserver,  tsigAlgorithm,  tsigKeyName,  tsigSecretSecretRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (nameserver != null) { sb.append("nameserver:"); sb.append(nameserver + ","); }
    if (tsigAlgorithm != null) { sb.append("tsigAlgorithm:"); sb.append(tsigAlgorithm + ","); }
    if (tsigKeyName != null) { sb.append("tsigKeyName:"); sb.append(tsigKeyName + ","); }
    if (tsigSecretSecretRef != null) { sb.append("tsigSecretSecretRef:"); sb.append(tsigSecretSecretRef); }
    sb.append("}");
    return sb.toString();
  }
  public class TsigSecretSecretRefNested<N> extends SecretKeySelectorFluent<TsigSecretSecretRefNested<N>> implements Nested<N>{
    TsigSecretSecretRefNested(SecretKeySelector item) {
      this.builder = new SecretKeySelectorBuilder(this, item);
    }
    SecretKeySelectorBuilder builder;
    public N and() {
      return (N) ACMEIssuerDNS01ProviderRFC2136Fluent.this.withTsigSecretSecretRef(builder.build());
    }
    public N endTsigSecretSecretRef() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha3-6.9.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEIssuerDNS01ProviderRFC2136Fluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorFluent;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorBuilder;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelector;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ACMEIssuerDNS01ProviderRFC2136Fluent<A extends ACMEIssuerDNS01ProviderRFC2136Fluent<A>> extends BaseFluent<A>{
  public ACMEIssuerDNS01ProviderRFC2136Fluent() {
  }
  
  public ACMEIssuerDNS01ProviderRFC2136Fluent(ACMEIssuerDNS01ProviderRFC2136 instance) {
    this.copyInstance(instance);
  }
  private String nameserver;
  private String tsigAlgorithm;
  private String tsigKeyName;
  private SecretKeySelectorBuilder tsigSecretSecretRef;
  
  protected void copyInstance(ACMEIssuerDNS01ProviderRFC2136 instance) {
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderRFC2136());
  
    if (instance != null) {
        this.withNameserver(instance.getNameserver());
        this.withTsigAlgorithm(instance.getTsigAlgorithm());
        this.withTsigKeyName(instance.getTsigKeyName());
        this.withTsigSecretSecretRef(instance.getTsigSecretSecretRef());
        this.withNameserver(instance.getNameserver());
        this.withTsigAlgorithm(instance.getTsigAlgorithm());
        this.withTsigKeyName(instance.getTsigKeyName());
        this.withTsigSecretSecretRef(instance.getTsigSecretSecretRef());
      }
  }
  
  public String getNameserver() {
    return this.nameserver;
  }
  
  public A withNameserver(String nameserver) {
    this.nameserver=nameserver; return (A) this;
  }
  
  public boolean hasNameserver() {
    return this.nameserver != null;
  }
  
  public String getTsigAlgorithm() {
    return this.tsigAlgorithm;
  }
  
  public A withTsigAlgorithm(String tsigAlgorithm) {
    this.tsigAlgorithm=tsigAlgorithm; return (A) this;
  }
  
  public boolean hasTsigAlgorithm() {
    return this.tsigAlgorithm != null;
  }
  
  public String getTsigKeyName() {
    return this.tsigKeyName;
  }
  
  public A withTsigKeyName(String tsigKeyName) {
    this.tsigKeyName=tsigKeyName; return (A) this;
  }
  
  public boolean hasTsigKeyName() {
    return this.tsigKeyName != null;
  }
  
  public SecretKeySelector buildTsigSecretSecretRef() {
    return this.tsigSecretSecretRef!=null ?this.tsigSecretSecretRef.build():null;
  }
  
  public A withTsigSecretSecretRef(SecretKeySelector tsigSecretSecretRef) {
    _visitables.get("tsigSecretSecretRef").remove(this.tsigSecretSecretRef);
    if (tsigSecretSecretRef!=null){ this.tsigSecretSecretRef= new SecretKeySelectorBuilder(tsigSecretSecretRef); _visitables.get("tsigSecretSecretRef").add(this.tsigSecretSecretRef);} else { this.tsigSecretSecretRef = null; _visitables.get("tsigSecretSecretRef").remove(this.tsigSecretSecretRef); } return (A) this;
  }
  
  public boolean hasTsigSecretSecretRef() {
    return this.tsigSecretSecretRef != null;
  }
  
  public A withNewTsigSecretSecretRef(String key,String name) {
    return (A)withTsigSecretSecretRef(new SecretKeySelector(key, name));
  }
  
  public TsigSecretSecretRefNested<A> withNewTsigSecretSecretRef() {
    return new TsigSecretSecretRefNested(null);
  }
  
  public TsigSecretSecretRefNested<A> withNewTsigSecretSecretRefLike(SecretKeySelector item) {
    return new TsigSecretSecretRefNested(item);
  }
  
  public TsigSecretSecretRefNested<A> editTsigSecretSecretRef() {
    return withNewTsigSecretSecretRefLike(java.util.Optional.ofNullable(buildTsigSecretSecretRef()).orElse(null));
  }
  
  public TsigSecretSecretRefNested<A> editOrNewTsigSecretSecretRef() {
    return withNewTsigSecretSecretRefLike(java.util.Optional.ofNullable(buildTsigSecretSecretRef()).orElse(new SecretKeySelectorBuilder().build()));
  }
  
  public TsigSecretSecretRefNested<A> editOrNewTsigSecretSecretRefLike(SecretKeySelector item) {
    return withNewTsigSecretSecretRefLike(java.util.Optional.ofNullable(buildTsigSecretSecretRef()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEIssuerDNS01ProviderRFC2136Fluent that = (ACMEIssuerDNS01ProviderRFC2136Fluent) o;
    if (!java.util.Objects.equals(nameserver, that.nameserver)) return false;
  
    if (!java.util.Objects.equals(tsigAlgorithm, that.tsigAlgorithm)) return false;
  
    if (!java.util.Objects.equals(tsigKeyName, that.tsigKeyName)) return false;
  
    if (!java.util.Objects.equals(tsigSecretSecretRef, that.tsigSecretSecretRef)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(nameserver,  tsigAlgorithm,  tsigKeyName,  tsigSecretSecretRef,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (nameserver != null) { sb.append("nameserver:"); sb.append(nameserver + ","); }
    if (tsigAlgorithm != null) { sb.append("tsigAlgorithm:"); sb.append(tsigAlgorithm + ","); }
    if (tsigKeyName != null) { sb.append("tsigKeyName:"); sb.append(tsigKeyName + ","); }
    if (tsigSecretSecretRef != null) { sb.append("tsigSecretSecretRef:"); sb.append(tsigSecretSecretRef); }
    sb.append("}");
    return sb.toString();
  }
  public class TsigSecretSecretRefNested<N> extends SecretKeySelectorFluent<TsigSecretSecretRefNested<N>> implements Nested<N>{
    TsigSecretSecretRefNested(SecretKeySelector item) {
      this.builder = new SecretKeySelectorBuilder(this, item);
    }
    SecretKeySelectorBuilder builder;
    
    public N and() {
      return (N) ACMEIssuerDNS01ProviderRFC2136Fluent.this.withTsigSecretSecretRef(builder.build());
    }
    
    public N endTsigSecretSecretRef() {
      return and();
    }
    
  
  }

}
